% C = GenerateConfusionMatrix(Atest, btest, X)
%
% Generates a matrix C whose entry
%
%  C(i, j) = Fraction of times that class j was correct but class i
%  was predicted.
%
% The diagonal of C is set to zero, but one may recover the fraction
% of times that class j was correct and also predicted as
%
%  1 - sum(C(:, j)).
%
% Also displays the resulting confusion matrix as a heat map.
function confusions = GenerateConfusionMatrix(Atest, btest, X);

b_preds = ClassifyAll(Atest, X);
confusions = zeros(10, 10);
Ntest = size(Atest, 1);
for ii = 1:Ntest
  confusions(b_preds(ii) + 1, btest(ii) + 1) = ...
      confusions(b_preds(ii) + 1, btest(ii) + 1) + 1;
end
for ii = 1:10
  total_i = sum(confusions(:, ii));
  confusions(ii, ii) = 0;
  confusions(:, ii) = confusions(:, ii) / total_i;
end
figure();
imshow(confusions / max(confusions(:)), ...
       'InitialMagnification', 3200, 'Colormap', hot);
xlabel('True label');
ylabel('Predicted label');

