% RunExperiment()
%
% Loads data, kernelizes it, and performs Projected Stochastic
% Gradient Descent. Prints results (in terms of final test error as
% well as final objective error).
function RunExperiment()

rng(0);

fprintf(1, 'Loading dataset\n');
[Atest, btest, Atrain, btrain] = LoadDatasets();
fprintf(1, 'Kernelizing dataset\n');
subsample_proportion = .2;
tau = .5;
[Ktrain, Ktest] = ...
    GetKernelRepresentation(Atrain, Atest, subsample_proportion, tau);
l2_radius_raw = 40.0;
M_raw = sqrt(mean(sum(Atrain.^2, 2)));
init_stepsize_raw = l2_radius_raw / M_raw;
l2_radius_kernel = 60.0;
M_kernel = sqrt(mean(sum(Ktrain.^2, 2)));
init_stepsize_kernel = l2_radius_kernel / M_kernel;
fprintf(1, 'Training SGD\n');
maxiter = 40000;
[X_raw, mean_X_raw] = ...
    sgd(Atrain, btrain, maxiter, init_stepsize_raw, l2_radius_raw);
fprintf(1, 'Training Kernel SGD\n');
[X_kern, mean_X_kern] = ...
    sgd(Ktrain, btrain, maxiter, init_stepsize_kernel, l2_radius_kernel);
Ntest = length(btest);
fprintf(1, '** Test error rate for raw data **\n\t');
fprintf(1,  '%f [last point]\n\t%f [mean of iterates]\n', ...
        sum(ClassifyAll(Atest, mean_X_raw) ~= btest) / Ntest, ...
        sum(ClassifyAll(Atest, X_raw) ~= btest) / Ntest);
fprintf(1, '** Test error rate for kernelized data **\n\t');
fprintf(1, '%f [last point]\n\t%f [mean of iterates]\n', ...
        sum(ClassifyAll(Ktest, X_kern) ~= btest) / Ntest, ...
        sum(ClassifyAll(Ktest, mean_X_kern) ~= btest) / Ntest);

GenerateConfusionMatrix(Atest, btest, X_raw);
title('Raw data confusion');
GenerateConfusionMatrix(Ktest, btest, mean_X_kern);
title('Kernelized data confusion');
