% function [X, mean_X] = sgd(Atrain, btrain, maxiter, init_stepsize, ...
%                            l2_radius)
%
% Performs maxiter iterations of projected stochastic gradient descent
% on the data contained in the matrix Atrain, of size N-by-d, where N
% is the sample size and d is the dimension, and the label vector
% btrain of integers in {0, 1, ..., 9}. Returns two d-by-10
% classification matrices X and mean_X, where the first is the final
% point of SGD and the second is the mean of all the iterates of SGD.
%
% Each iteration consists of choosing a random index from N and the
% associated data point in A, taking a subgradient step for the
% multiclass SVM objective, and projecting onto the set
%
%   {X : ||X||_{Fr} <= l2_radius}
%
% where ||.||_{Fr} is the Frobenius norm (vector Euclidean norm) on
% its argument.
%
% The stepsize is init_stepsize / sqrt(iteration).
function [X, mean_X] = sgd(Atrain, btrain, maxiter, init_stepsize, ...
                           l2_radius)
if (nargin < 3)
  maxiter = 10000;
end
if (nargin < 4)
  init_stepsize = 1.0;
end
if (nargin < 5)
  l2_radius = Inf;
end
K = 10;
[NN, dd] = size(Atrain);
X = zeros(dd, K);
mean_X = zeros(dd, K);

%% YOUR CODE HERE -- IMPLEMENT PROJECTED STOCHASTIC GRADIENT DESCENT
for iter = 1:maxiter




end
